*  Program...........: TRNSFRST.PRG
*  Author............: Ken R. Levy
*  Project...........: Transporter
*  Created...........: 08/12/1994  22:00:00
*  Copyright.........: (Public Domain) Flash Creative Management, Inc., 1994
*  Copyright.........: (Public Domain) Jet Propulsion Laboratory, 1993-1994
*) Description.......: Preprocessor for TRANSPRT.PRG using GENSCRNX
*  Calling Samples...: 
*  Parameter List....: 
*  Major change list.: 
*
*  Preprocessor for TRANSPRT.PRG using GENSCRNX.
*  Used to surpress Transporter dialog when loading the PTX Editor.
*  Used for automatic transporting of updating Comment snippets.
*  This program executes before the transporter with the following in the
*  CONFIG.FP/FPW:
*
*  _TRANSPORT="<path>GENSCRNX.PRG"
*  _TRNDRV1="<path>TRNSFRST.PRG"
*  _TRNDRV2="<path>TRNSLAST.PRG"
*
*  Note:
*  _TRNDRV2 above is optional and is independent of _TRNDRV1.
*  When editing snippets (including Comment snippet) with the PTX Editor,
*  all platform snippets are updated when saving.

PARAMETER g_scrndbf,tp_filetype,dummy

PRIVATE lnCount,lcProgName
PRIVATE lcPlatform,lnLastSel,lcTempCDX,lcUniqueID
PRIVATE lnTmStmpOld,lnTmStmpNew,lcCmntOld,lcCmntNew
PRIVATE lnRecNoOld,lnRecNoNew,lnRecNo

*-- Loop to check of PTX Editor is running to abort transporter dialog.
FOR lnCount = 1 TO 32
  lcProgName=UPPER(ALLTRIM(PROGRAM(lnCount)))
  IF EMPTY(lcProgName)
    EXIT
  ENDIF
  IF lcProgName=='PTXEDT'
    gstatus=-2
    EXIT
  ENDIF
ENDFOR

*-- Abort of non-.SCX file.
IF NOT UPPER(RIGHT(g_scrndbf,4))=='.SCX'
  RETURN .T.
ENDIF

*-- Set lcPlatform to character string of current platform.
DO CASE
  CASE _WINDOWS
    lcPlatform='WINDOWS'
  CASE _MAC
    lcPlatform='MAC'
  CASE _UNIX
    lcPlatform='UNIX'
  OTHERWISE
    lcPlatform='DOS'
ENDCASE
lcPlatform=PADR(lcPlatform,8)

*-- Save current work area.
lnLastSel=SELECT()

*-- Create temp file name for index
lcTempCDX=SYS(3)+'.CDX'

*-- Open .SCX file being transported.
SELECT 0
USE (g_scrndbf)

*-- Create temporary index for scanning on UNIQUEID field.
INDEX ON UNIQUEID TAG UNIQUEID OF (lcTempCDX)

SCAN ALL
  lnRecNo=RECNO()
  lnTmStmpOld=0
  lnTmStmpNew=0
  lcCmntOld=''
  lcCmntNew=''
  lnRecNoOld=0
  lnRecNoNew=0
  lcUniqueID=UNIQUEID

  *-- Scan next records with matching UNIQUEID fields.
  SCAN REST WHILE UNIQUEID==lcUniqueID

    DO CASE

      *-- Set memvars for current platform.
      CASE PLATFORM==lcPlatform
        lnRecNoOld=RECNO()
        lnTmStmpOld=TIMESTAMP
        lcCmntOld=COMMENT

      *-- Set memvars for non-current platform with more recent TIMESTAMP.
      CASE TIMESTAMP>lnTmStmpNew
        lnRecNoNew=RECNO()
        lnTmStmpNew=TIMESTAMP
        lcCmntNew=COMMENT

    ENDCASE

  ENDSCAN

  *-- Update COMMENT snippet if required.
  IF lnRecNoOld>0 AND lnTmStmpNew>lnTmStmpOld AND NOT lcCmntOld==lcCmntNew
    GOTO lnRecNoOld
    REPLACE COMMENT WITH lcCmntNew
    GOTO lnRecNo
    SKIP
  ENDIF

  SKIP -1
ENDSCAN

*-- Close .SCX table, delete temporary index file, and restore work area.
USE
ERASE (lcTempCDX)
SELECT (lnLastSel)

*-- Return to GENSCRNX.
RETURN .T.

* END TRNSFRST.PRG
